#!/usr/bin/env python
from io import open
from setuptools import setup, find_packages
setup(
    name='pythonic-bert',
    version='1.7.7',
    description='a package for your bert using',
    long_description='使用pytorch实现你的bert项目',
    author='xiaoguzai',
    author_email='474551240@qq.com',
    license='Apache License 2.0',
    url='https://github.com/boss2020/pytorch-transformer',
    download_url='https://github.com/boss2020/pytorch-transformer/master.zip',
    packages=find_packages(),
)
